R/BiocPkgDOI_mint_by_REST.R
generateBiocPkgDOI_REST.RdThis function makes calls out to the REST API (v2) described here: https://support.datacite.org/docs/api-create-dois. This function creates a new DOI for a Bioconductor package (cannot already exist). The target URL for the DOI is the short Bioconductor package URL.
generateBiocPkgDOI_REST(pkg, authors, pubyear, testing = TRUE)character(1) package name
character vector of authors (will be "pasted" together)
integer(1) publication year
logical(1) If true, will use the apitest user with the password apitest. These DOIs will expire. The same apitest:apitest combination can be used to login to the EZID website for doing things using the web interface. If false, the Bioconductor-specific user credentials should be in the correct environment variables
The DOI as a character(1) vector.
The login information for the "real" Bioconductor account should be stored in the environment variables "EZID_USERNAME" and "EZID_PASSWORD".
The GUI is available here: https://doi.datacite.org/.
if (FALSE) { # \dontrun{
x = generateBiocPkgDOI('RANDOM_TEST_PACKAGE','Sean Davis',1972)
} # }