List all the packages associated with a maintainer. By default, it will return all packages associated with the maintainer@bioconductor.org email. hasBiocMaint returns a logical vector corresponding to the input character vector of packages indicating whether any package is maintained by the Bioconductor core team.

biocMaintained(
  main = "maintainer@bioconductor.org",
  version = BiocManager::version(),
  pkgType = c("software", "data-experiment", "workflows", "data-annotation")
)

hasBiocMaint(
  pkg,
  version = BiocManager::version(),
  main = "maintainer@bioconductor\\.org",
  repo = c("BioCsoft", "BioCexp", "BioCworkflows", "BioCann")
)

Arguments

main

character(1) A regex string to search for in the Maintainer column from the biocPkgList() output.

version

character(1) or package_version indicating the Bioconductor version (e.g., "3.22"). Defaults to the "current version" provided by BiocManager::version(). The keywords "release" and "devel" are also accepted.

pkgType

character() The type of packages for which to get information for. Values can be one or more of the following:

  • software: Software packages

  • data-experiment: Experiment data packages

  • data-annotation: Annotation data packages

  • workflows: Workflow packages

pkg

character(1) A vector of package names (case sensitive).

repo

character() A vector of Bioconductor repositories to search through. By default, it will search through all Bioconductor repositories.

Value

For biocMaintained: a tibble of packages associated with the maintainer.

For hasBiocMaint: a logical vector indicating whether the package is maintained by Bioconductor.

Examples


biocMaintained()
#> 'getOption("repos")' replaces Bioconductor standard repositories, see
#> 'help("repositories", package = "BiocManager")' for details.
#> Replacement repositories:
#>     CRAN: https://cran.rstudio.com
#> # A tibble: 592 × 32
#>    Package        Version Depends Suggests License MD5sum NeedsCompilation Title
#>    <chr>          <chr>   <list>  <list>   <chr>   <chr>  <chr>            <chr>
#>  1 annotate       1.90.0  <chr>   <chr>    Artist… 005b6… no               "Ann…
#>  2 AnnotationDbi  1.74.0  <chr>   <chr>    Artist… 65b70… no               "Man…
#>  3 AnnotationFil… 1.36.0  <chr>   <chr>    Artist… a7973… no               "Fac…
#>  4 AnnotationFor… 1.54.0  <chr>   <chr>    Artist… d45f6… no               "Too…
#>  5 AnnotationHub  4.2.0   <chr>   <chr>    Artist… 6fcb2… yes              "Cli…
#>  6 AnnotationHub… 1.42.0  <chr>   <chr>    Artist… db4d5… no               "Tra…
#>  7 Biobase        2.72.0  <chr>   <chr>    Artist… b3b23… yes              "Bio…
#>  8 Bioc.gff       1.2.0   <chr>   <chr>    Artist… 817a4… yes              "Rea…
#>  9 BiocStyle      2.40.0  <chr>   <chr>    Artist… 965b4… no               "Sta…
#> 10 BiocVersion    3.23.1  <chr>   <chr>    Artist… 1ea22… no               "Set…
#> # ℹ 582 more rows
#> # ℹ 24 more variables: Description <chr>, biocViews <list>, Author <list>,
#> #   Maintainer <list>, git_url <chr>, git_branch <chr>, git_last_commit <chr>,
#> #   git_last_commit_date <chr>, `Date/Publication` <chr>, source.ver <chr>,
#> #   vignettes <list>, vignetteTitles <list>, hasREADME <chr>, hasNEWS <chr>,
#> #   hasINSTALL <chr>, hasLICENSE <chr>, Rfiles <list>, dependencyCount <chr>,
#> #   Imports <list>, suggestsMe <list>, VignetteBuilder <chr>, URL <chr>, …

## maintained by Hervé and not maintainer at bioconductor dot org
hasBiocMaint("BiocGenerics")
#> 'getOption("repos")' replaces Bioconductor standard repositories, see
#> 'help("repositories", package = "BiocManager")' for details.
#> Replacement repositories:
#>     CRAN: https://cran.rstudio.com
#> BiocGenerics 
#>        FALSE