The BiocViews-generated VIEWS file is available for Bioconductor release and devel repositories. It contains quite a bit more information from the package DESCRIPTION files than the PACKAGES file. In particular, it contains biocViews annotations and URLs for vignettes and developer URLs.

biocPkgList(
  version = BiocManager::version(),
  repo = c("BioCsoft", "BioCexp", "BioCworkflows", "BioCann", "CRAN"),
  addBiocViewParents = TRUE
)

Arguments

version

character(1) or package_version indicating the Bioconductor version (e.g., "3.22"). Defaults to the "current version" provided by BiocManager::version(). The keywords "release" and "devel" are also accepted.

repo

character(1) The requested Bioconductor repository. The default is to pull from the "BioCsoft" repository. Possible repositories include "BioCsoft", "BioCexp", "BioCworkflows", "BioCann", and "CRAN". Note that not all repos are available for all versions, particularly older versions.

addBiocViewParents

logical(1) whether to add all biocViews parents to biocViews annotations.

Value

An object of class tbl_df with one row per package. The result always includes a fnd list-column whose elements are character vectors of funder names extracted from persons with role "fnd" in the formatted Author field. Elements are NA_character_ for packages that declare no funder (or whose Author field contains no [fnd] role tag).

Details

Since packages are annotated with the most specific views, the default functionality here is to add parent terms for all views for each package. For example, in the bioCsoft repository, all packages will have at least "Software" added to their biocViews. If one wants to stick to only the most specific terms, set addBiocViewParents to FALSE.

Examples

bpkgl <- biocPkgList(repo = "BioCsoft")
#> 'getOption("repos")' replaces Bioconductor standard repositories, see
#> 'help("repositories", package = "BiocManager")' for details.
#> Replacement repositories:
#>     CRAN: https://cran.rstudio.com
bpkgl
#> # A tibble: 2,418 × 48
#>    Package     Version Depends   Suggests  License MD5sum NeedsCompilation Title
#>    <chr>       <chr>   <list>    <list>    <chr>   <chr>  <chr>            <chr>
#>  1 a4          1.60.0  <chr [5]> <chr [7]> GPL-3   9e320… no               "Aut…
#>  2 a4Base      1.60.0  <chr [2]> <chr [4]> GPL-3   e7fc4… no               "Aut…
#>  3 a4Classif   1.60.0  <chr [2]> <chr [4]> GPL-3   07449… no               "Aut…
#>  4 a4Core      1.60.0  <chr [1]> <chr [2]> GPL-3   839c3… no               "Aut…
#>  5 a4Preproc   1.60.0  <chr [1]> <chr [4]> GPL-3   c3c7d… no               "Aut…
#>  6 a4Reporting 1.60.0  <chr [1]> <chr [2]> GPL-3   20801… no               "Aut…
#>  7 ABarray     1.80.0  <chr [1]> <chr [2]> GPL     95858… no               "Mic…
#>  8 abseqR      1.30.0  <chr [1]> <chr [1]> GPL-3 … 934b6… no               "Rep…
#>  9 ABSSeq      1.66.0  <chr [2]> <chr [1]> GPL (>… e84a3… no               "ABS…
#> 10 acde        1.42.0  <chr [2]> <chr [2]> GPL-3   0ddff… no               "Art…
#> # ℹ 2,408 more rows
#> # ℹ 40 more variables: Description <chr>, biocViews <list>, Author <list>,
#> #   Maintainer <list>, git_url <chr>, git_branch <chr>, git_last_commit <chr>,
#> #   git_last_commit_date <chr>, `Date/Publication` <chr>, source.ver <chr>,
#> #   win.binary.ver <chr>, `mac.binary.big-sur-x86_64.ver` <chr>,
#> #   `mac.binary.sonoma-arm64.ver` <chr>, vignettes <list>,
#> #   vignetteTitles <list>, hasREADME <chr>, hasNEWS <chr>, hasINSTALL <chr>, …
unlist(bpkgl[1,'Depends'], use.names = FALSE)
#> [1] "a4Base"      "a4Preproc"   "a4Classif"   "a4Core"      "a4Reporting"

# Get a list of all packages that
# import "GEOquery"
library(dplyr)
#> 
#> Attaching package: ‘dplyr’
#> The following objects are masked from ‘package:stats’:
#> 
#>     filter, lag
#> The following objects are masked from ‘package:base’:
#> 
#>     intersect, setdiff, setequal, union
bpkgl |>
  filter(Package == 'GEOquery') |>
  pull('importsMe') |>
  unlist()
#>  [1] "bigmelon"                       "ChIPXpress"                    
#>  [3] "DExMA"                          "EGAD"                          
#>  [5] "minfi"                          "Moonlight2R"                   
#>  [7] "MoonlightR"                     "phantasus"                     
#>  [9] "recount"                        "BeadArrayUseCases"             
#> [11] "BioPlex"                        "GSE13015"                      
#> [13] "healthyControlsPresenceChecker" "geneExpressionFromGEO"         
#> [15] "RCPA"